==> apache-kyuubi-1.7.0-source.tgz: apache-kyuubi-1.7.0-source/extensions/spark/kyuubi-spark-connector-hive/src/main/scala/org/apache/kyuubi/spark/connector/hive/read/HiveScanBuilder.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kyuubi.spark.connector.hive.read

import org.apache.spark.sql.SparkSession
import org.apache.spark.sql.catalyst.catalog.CatalogTable
import org.apache.spark.sql.connector.read.Scan
import org.apache.spark.sql.execution.datasources.v2.FileScanBuilder
import org.apache.spark.sql.types.StructType

case class HiveScanBuilder(
    sparkSession: SparkSession,
    fileIndex: HiveCatalogFileIndex,
    dataSchema: StructType,
    table: CatalogTable)
  extends FileScanBuilder(sparkSession, fileIndex, dataSchema) {

  override def build(): Scan = {
    HiveScan(
      sparkSession = sparkSession,
      fileIndex = fileIndex,
      catalogTable = table,
      dataSchema = dataSchema,
      readDataSchema = readDataSchema(),
      readPartitionSchema = readPartitionSchema())
  }
}

==> apache-kyuubi-1.11.0-source.tgz: apache-kyuubi-1.11.0-source/extensions/spark/kyuubi-spark-connector-hive/src/main/scala/org/apache/kyuubi/spark/connector/hive/read/HiveScanBuilder.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kyuubi.spark.connector.hive.read

import org.apache.spark.sql.SparkSession
import org.apache.spark.sql.catalyst.catalog.CatalogTable
import org.apache.spark.sql.connector.read.Scan
import org.apache.spark.sql.execution.datasources.v2.FileScanBuilder
import org.apache.spark.sql.types.StructType

case class HiveScanBuilder(
    sparkSession: SparkSession,
    fileIndex: HiveCatalogFileIndex,
    dataSchema: StructType,
    table: CatalogTable)
  extends FileScanBuilder(sparkSession, fileIndex, dataSchema) {

  override def build(): Scan = {
    HiveScan(
      sparkSession = sparkSession,
      fileIndex = fileIndex,
      catalogTable = table,
      dataSchema = dataSchema,
      readDataSchema = readDataSchema(),
      readPartitionSchema = readPartitionSchema(),
      partitionFilters = partitionFilters,
      dataFilters = dataFilters)
  }
}
